Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(721)

Unified Diff: chrome/browser/ui/ash/app_list/app_list_shower_ash.h

Issue 1770993002: wip: Refactoring Ash's AppListController, moving the bulk of the logic to chrome/browser/ui/ash/app… Base URL: https://chromium.googlesource.com/chromium/src.git@small_5_apps
Patch Set: Added a comment for PostTask in AppListServiceAsh. Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/ash/app_list/app_list_shower_ash.h
diff --git a/ash/wm/app_list_controller.h b/chrome/browser/ui/ash/app_list/app_list_shower_ash.h
similarity index 47%
rename from ash/wm/app_list_controller.h
rename to chrome/browser/ui/ash/app_list/app_list_shower_ash.h
index 1f3114c37d4858c4bfda875bd5e4fb9696d9a4d5..36950df366516b006b2066583f6647b9f10f0718 100644
--- a/ash/wm/app_list_controller.h
+++ b/chrome/browser/ui/ash/app_list/app_list_shower_ash.h
@@ -1,66 +1,44 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef ASH_WM_APP_LIST_CONTROLLER_H_
-#define ASH_WM_APP_LIST_CONTROLLER_H_
+#ifndef CHROME_BROWSER_UI_ASH_APP_LIST_APP_LIST_SHOWER_ASH_H_
+#define CHROME_BROWSER_UI_ASH_APP_LIST_APP_LIST_SHOWER_ASH_H_
-#include "ash/shelf/shelf_icon_observer.h"
-#include "ash/shell_observer.h"
#include "base/compiler_specific.h"
#include "base/macros.h"
+#include "chrome/browser/ui/app_list/app_list_controller_delegate.h"
+#include "chrome/browser/ui/ash/launcher/chrome_launcher_types.h"
+#include "ui/app_list/app_list_controller.h"
+#include "ui/app_list/app_list_layout_delegate.h"
#include "ui/app_list/pagination_model_observer.h"
#include "ui/aura/client/focus_change_observer.h"
#include "ui/aura/window_observer.h"
#include "ui/compositor/layer_animation_observer.h"
-#include "ui/events/event_handler.h"
#include "ui/gfx/geometry/rect.h"
#include "ui/keyboard/keyboard_controller_observer.h"
#include "ui/views/widget/widget_observer.h"
namespace app_list {
-class ApplicationDragAndDropHost;
class AppListView;
}
-namespace ui {
-class LocatedEvent;
-}
-
-namespace ash {
-namespace test {
-class AppListControllerTestApi;
-}
-
-// AppListController is a controller that manages app list UI for shell.
-// It creates AppListView and schedules showing/hiding animation.
-// While the UI is visible, it monitors things such as app list widget's
-// activation state and desktop mouse click to auto dismiss the UI.
-class AppListController : public ui::EventHandler,
- public aura::client::FocusChangeObserver,
- public aura::WindowObserver,
- public ui::ImplicitAnimationObserver,
- public views::WidgetObserver,
- public keyboard::KeyboardControllerObserver,
- public ShellObserver,
- public ShelfIconObserver,
- public app_list::PaginationModelObserver {
+class AppListViewDelegate;
+
+// Manages app list UI. Creates AppListView and schedules showing/hiding
+// animation. While the UI is visible, it monitors things such as app list
+// activation state to auto dismiss the UI. Delegates the responsibility
+// for laying out the app list UI to ash::AppListLayoutDelegate.
+class AppListShowerAsh : public app_list::AppListController,
+ public aura::client::FocusChangeObserver,
+ public aura::WindowObserver,
+ public ui::ImplicitAnimationObserver,
+ public views::WidgetObserver,
+ public keyboard::KeyboardControllerObserver,
+ public app_list::PaginationModelObserver {
public:
- AppListController();
- ~AppListController() override;
-
- // Show/hide app list window. The |window| is used to deterime in
- // which display (in which the |window| exists) the app list should
- // be shown.
- void Show(aura::Window* window);
- void Dismiss();
-
- // Whether app list window is visible (shown or being shown).
- bool IsVisible() const;
-
- // Returns target visibility. This differs from IsVisible() if an animation
- // is ongoing.
- bool GetTargetVisibility() const { return is_visible_; }
+ AppListShowerAsh();
+ ~AppListShowerAsh() override;
// Returns app list window or NULL if it is not visible.
aura::Window* GetWindow();
@@ -68,13 +46,18 @@ class AppListController : public ui::EventHandler,
// Returns app list view if one exists, or NULL otherwise.
app_list::AppListView* GetView() { return view_; }
- private:
- friend class test::AppListControllerTestApi;
+ void set_view_delegate(AppListViewDelegate* view_delegate) {
+ view_delegate_ = view_delegate;
+ }
- // If |drag_and_drop_host| is not NULL it will be called upon drag and drop
- // operations outside the application list.
- void SetDragAndDropHostOfCurrentAppList(
- app_list::ApplicationDragAndDropHost* drag_and_drop_host);
+ // app_list::AppListController:
+ void Show(aura::Window* window) override;
+ void Dismiss() override;
+ bool IsVisible() const override;
+ bool GetTargetVisibility() const override;
+
+ private:
+// friend class test::AppListControllerTestApi;
// Sets the app list view and attempts to show it.
void SetView(app_list::AppListView* view);
@@ -85,15 +68,6 @@ class AppListController : public ui::EventHandler,
// Starts show/hide animation.
void ScheduleAnimation();
- void ProcessLocatedEvent(ui::LocatedEvent* event);
-
- // Makes app list bubble update its bounds.
- void UpdateBounds();
-
- // ui::EventHandler overrides:
- void OnMouseEvent(ui::MouseEvent* event) override;
- void OnGestureEvent(ui::GestureEvent* event) override;
-
// aura::client::FocusChangeObserver overrides:
void OnWindowFocused(aura::Window* gained_focus,
aura::Window* lost_focus) override;
@@ -112,26 +86,21 @@ class AppListController : public ui::EventHandler,
// KeyboardControllerObserver overrides:
void OnKeyboardBoundsChanging(const gfx::Rect& new_bounds) override;
- // ShellObserver overrides:
- void OnShelfAlignmentChanged(aura::Window* root_window) override;
- void OnMaximizeModeStarted() override;
- void OnMaximizeModeEnded() override;
-
- // ShelfIconObserver overrides:
- void OnShelfIconPositionsChanged() override;
-
// app_list::PaginationModelObserver overrides:
void TotalPagesChanged() override;
void SelectedPageChanged(int old_selected, int new_selected) override;
void TransitionStarted() override;
void TransitionChanged() override;
+ // Responsible for laying out the app list UI.
+ scoped_ptr<app_list::AppListLayoutDelegate> layout_delegate_;
+
+ // Not owned.
+ AppListViewDelegate* view_delegate_;
+
// Whether we should show or hide app list widget.
bool is_visible_;
- // Whether the app list should remain centered.
- bool is_centered_;
-
// The AppListView this class manages, owned by its widget.
app_list::AppListView* view_;
@@ -144,10 +113,6 @@ class AppListController : public ui::EventHandler,
// Whether should schedule snap back animation.
bool should_snap_back_;
-
- DISALLOW_COPY_AND_ASSIGN(AppListController);
};
-} // namespace ash
-
-#endif // ASH_WM_APP_LIST_CONTROLLER_H_
+#endif // CHROME_BROWSER_UI_ASH_APP_LIST_APP_LIST_SHOWER_ASH_H_

Powered by Google App Engine
This is Rietveld 408576698